shutdown_llvm

Function shutdown_llvm 

pub unsafe fn shutdown_llvm()
This function is very unsafe. Any reference to LLVM data after this function is called will likely segfault. Probably only ever useful to call before your program ends. Might not even be absolutely necessary.