pub fn load_library_permanently(path: &Path) -> Result<(), LoadLibraryError>Expand description
Permanently load the dynamic library at the given path.
It is safe to call this function multiple times for the same library.
pub fn load_library_permanently(path: &Path) -> Result<(), LoadLibraryError>Permanently load the dynamic library at the given path.
It is safe to call this function multiple times for the same library.